@@ -42,7 +42,7 @@ from airflow import settings
 from airflow.api_fastapi.app import create_auth_manager, get_auth_manager
 from airflow.configuration import conf
 from airflow.providers.fab.www.security_manager import AirflowSecurityManagerV2
-from airflow.providers.fab.www.views import FabIndexView
+from airflow.providers.fab.www.views import FabIndexView, redirect
 
 if TYPE_CHECKING:
     from flask import Flask
@@ -80,8 +80,6 @@ class AirflowAppBuilder:
     """This is the base class for all the framework."""
 
     baseviews: list[BaseView | Session] = []
-    # Flask app
-    app = None
     # Database Session
     session = None
     # Security Manager Class
@@ -149,7 +147,6 @@ class AirflowAppBuilder:
         self.indexview = indexview
         self.static_folder = static_folder
         self.static_url_path = static_url_path
-        self.app = app
         self.enable_plugins = enable_plugins
         self.update_perms = conf.getboolean("fab", "UPDATE_FAB_PERMS")
         self.auth_rate_limited = conf.getboolean("fab", "AUTH_RATE_LIMITED")
@@ -164,6 +161,7 @@ class AirflowAppBuilder:
         :param app:
         :param session: The SQLAlchemy session
         """
+        log.info("Initializing AppBuilder")
         app.config.setdefault("APP_NAME", "F.A.B.")
         app.config.setdefault("APP_THEME", "")
         app.config.setdefault("APP_ICON", "")
@@ -176,8 +174,6 @@ class AirflowAppBuilder:
         app.config.setdefault("AUTH_RATE_LIMITED", self.auth_rate_limited)
         app.config.setdefault("AUTH_RATE_LIMIT", self.auth_rate_limit)
 
-        self.app = app
-
         self.base_template = app.config.get("FAB_BASE_TEMPLATE", self.base_template)
         self.static_folder = app.config.get("FAB_STATIC_FOLDER", self.static_folder)
         self.static_url_path = app.config.get("FAB_STATIC_URL_PATH", self.static_url_path)
@@ -198,7 +194,8 @@ class AirflowAppBuilder:
         self.session = session
         auth_manager = create_auth_manager()
         auth_manager.appbuilder = self
-        auth_manager.init()
+        if hasattr(auth_manager, "init_flask_resources"):
+            auth_manager.init_flask_resources()
         if hasattr(auth_manager, "security_manager"):
             self.sm = auth_manager.security_manager
         else:
@@ -219,6 +216,7 @@ class AirflowAppBuilder:
         from airflow.providers.fab.www.views import get_safe_url
 
         fab_sec_views.get_safe_redirect = get_safe_url
+        fab_sec_views.redirect = redirect
 
     def _init_extension(self, app):
         app.appbuilder = self
@@ -227,25 +225,19 @@ class AirflowAppBuilder:
         app.extensions["appbuilder"] = self
 
     @property
-    def get_app(self):
-        """
-        Get current or configured flask app.
-
-        :return: Flask App
-        """
-        if self.app:
-            return self.app
-        else:
-            return current_app
+    def app(self) -> Flask:
+        log.warning(
+            "appbuilder.app is deprecated and will be removed in a future version. Use current_app instead"
+        )
+        return current_app
 
     @property
-    def get_session(self):
-        """
-        Get the current sqlalchemy session.
-
-        :return: SQLAlchemy Session
-        """
-        return self.session
+    def get_app(self) -> Flask:
+        log.warning(
+            "appbuilder.get_app is deprecated and will be removed in a future version. "
+            "Use current_app instead"
+        )
+        return self.app
 
     @property
     def app_name(self):
@@ -254,7 +246,7 @@ class AirflowAppBuilder:
 
         :return: String with app name
         """
-        return self.get_app.config["APP_NAME"]
+        return current_app.config["APP_NAME"]
 
     @property
     def app_theme(self):
@@ -263,7 +255,7 @@ class AirflowAppBuilder:
 
         :return: String app theme name
         """
-        return self.get_app.config["APP_THEME"]
+        return current_app.config["APP_THEME"]
 
     @property
     def app_icon(self):
@@ -272,11 +264,11 @@ class AirflowAppBuilder:
 
         :return: String with relative app icon location
         """
-        return self.get_app.config["APP_ICON"]
+        return current_app.config["APP_ICON"]
 
     @property
     def languages(self):
-        return self.get_app.config["LANGUAGES"]
+        return current_app.config["LANGUAGES"]
 
     @property
     def version(self):
@@ -288,7 +280,7 @@ class AirflowAppBuilder:
         return __version__
 
     def _add_global_filters(self):
-        self.template_filters = TemplateFilters(self.get_app, self.sm)
+        self.template_filters = TemplateFilters(current_app, self.sm)
 
     def _add_global_static(self):
         bp = Blueprint(
@@ -299,14 +291,16 @@ class AirflowAppBuilder:
             static_folder=self.static_folder,
             static_url_path=self.static_url_path,
         )
-        self.get_app.register_blueprint(bp)
+        current_app.register_blueprint(bp)
 
     def _add_admin_views(self):
         """Register indexview, utilview (back function), babel views and Security views."""
         self.indexview = self._check_and_init(self.indexview)
         self.add_view_no_menu(self.indexview)
         self.add_view_no_menu(UtilView())
-        get_auth_manager().register_views()
+        auth_manager = get_auth_manager()
+        if hasattr(auth_manager, "register_views"):
+            auth_manager.register_views()
 
     def _add_addon_views(self):
         """Register declared addons."""
@@ -326,8 +320,6 @@ class AirflowAppBuilder:
                     log.error(LOGMSG_ERR_FAB_ADDON_PROCESS, addon, e)
 
     def _check_and_init(self, baseview):
-        if hasattr(baseview, "datamodel"):
-            baseview.datamodel.session = self.session
         if callable(baseview):
             baseview = baseview()
         return baseview
@@ -407,16 +399,15 @@ class AirflowAppBuilder:
             appbuilder.add_link("google", href="www.google.com", icon="fa-google-plus")
         """
         baseview = self._check_and_init(baseview)
-        log.info(LOGMSG_INF_FAB_ADD_VIEW, baseview.__class__.__name__, name)
+        log.debug(LOGMSG_INF_FAB_ADD_VIEW, baseview.__class__.__name__, name)
 
         if not self._view_exists(baseview):
             baseview.appbuilder = self
             self.baseviews.append(baseview)
             self._process_inner_views()
-            if self.app:
-                self.register_blueprint(baseview)
-                self._add_permission(baseview)
-                self.add_limits(baseview)
+            self.register_blueprint(baseview)
+            self._add_permission(baseview)
+            self.add_limits(baseview)
         self.add_link(
             name=name,
             href=href,
@@ -510,19 +501,26 @@ class AirflowAppBuilder:
         :param baseview: A BaseView type class instantiated.
         """
         baseview = self._check_and_init(baseview)
-        log.info(LOGMSG_INF_FAB_ADD_VIEW, baseview.__class__.__name__, "")
+        log.debug(LOGMSG_INF_FAB_ADD_VIEW, baseview.__class__.__name__, "")
 
         if not self._view_exists(baseview):
             baseview.appbuilder = self
             self.baseviews.append(baseview)
             self._process_inner_views()
-            if self.app:
-                self.register_blueprint(baseview, endpoint=endpoint, static_folder=static_folder)
-                self._add_permission(baseview)
+            self.register_blueprint(baseview, endpoint=endpoint, static_folder=static_folder)
+            self._add_permission(baseview)
         else:
             log.warning(LOGMSG_WAR_FAB_VIEW_EXISTS, baseview.__class__.__name__)
         return baseview
 
+    def add_api(self, baseview):
+        """
+        Add a BaseApi class or child to AppBuilder.
+
+        :param baseview: A BaseApi type class
+        """
+        return self.add_view_no_menu(baseview)
+
     @property
     def get_url_for_index(self):
         return url_for(f"{self.indexview.endpoint}.{self.indexview.default_view}")
@@ -530,6 +528,10 @@ class AirflowAppBuilder:
     def get_url_for_login_with(self, next_url: str | None = None) -> str:
         return get_auth_manager().get_url_login(next_url=next_url)
 
+    @property
+    def get_url_for_login(self):
+        return get_auth_manager().get_url_login()
+
     def get_url_for_locale(self, lang):
         return url_for(
             f"{self.bm.locale_view.endpoint}.{self.bm.locale_view.default_view}",
@@ -543,7 +545,8 @@ class AirflowAppBuilder:
     def _add_permission(self, baseview, update_perms=False):
         if self.update_perms or update_perms:
             try:
-                self.sm.add_permissions_view(baseview.base_permissions, baseview.class_permission_name)
+                if hasattr(self.sm, "add_permissions_view"):
+                    self.sm.add_permissions_view(baseview.base_permissions, baseview.class_permission_name)
             except Exception as e:
                 log.exception(e)
                 log.error(LOGMSG_ERR_FAB_ADD_PERMISSION_VIEW, e)
@@ -557,7 +560,8 @@ class AirflowAppBuilder:
     def _add_permissions_menu(self, name, update_perms=False):
         if self.update_perms or update_perms:
             try:
-                self.sm.add_permissions_menu(name)
+                if hasattr(self.sm, "add_permissions_menu"):
+                    self.sm.add_permissions_menu(name)
             except Exception as e:
                 log.exception(e)
                 log.error(LOGMSG_ERR_FAB_ADD_PERMISSION_MENU, e)
@@ -572,7 +576,7 @@ class AirflowAppBuilder:
                         self._add_permissions_menu(item.name, update_perms=update_perms)
 
     def register_blueprint(self, baseview, endpoint=None, static_folder=None):
-        self.get_app.register_blueprint(
+        current_app.register_blueprint(
             baseview.create_blueprint(self, endpoint=endpoint, static_folder=static_folder)
         )
 
@@ -589,9 +593,11 @@ class AirflowAppBuilder:
 
 def init_appbuilder(app: Flask, enable_plugins: bool) -> AirflowAppBuilder:
     """Init `Flask App Builder <https://flask-appbuilder.readthedocs.io/en/latest/>`__."""
+    if settings.Session is None:
+        raise RuntimeError("Session not configured. Call configure_orm() first.")
     return AirflowAppBuilder(
         app=app,
-        session=settings.Session,
+        session=settings.Session(),
         base_template="airflow/main.html",
         enable_plugins=enable_plugins,
     )
